
/*******************************************************************

   	Macro:       fiscal;
   	Author:      Harry Droogendyk        harry@stratia.ca
   	Date:        2008/07/12

   	Returns formated dates in reference to banking fiscal year.

/*******************************************************************/

%macro fiscal(help,date=,format=year.);

	%if &help = ? or %upcase(&help) = HELP %then %do;
		%put ;
		%put %nrstr(%fiscal(date=,format=););
		%put %nrstr(Returns date relative to bank fiscal year for the supplied SAS internal date.);
		%put %nrstr(Parms: &date   - SAS variable containing internal date value);
		%put %nrstr(       &format - output format, eg. month., year., yymmn6., yyq6.);
		%put %nrstr(Use:   fiscal = %fiscal(date=sas_date_variable,format=format););

	%end; %else %do;
	  	  
		%if &sysprocname = %then %do;						%*  executing from macro ;
			%sysfunc(intnx(month,&date,2),&format) 
		%end; %else %do;									%*  executing from data or SQL step ;	
			put(intnx('month',&date,2),&format)
		%end;

	%end;

%mend fiscal;

%fiscal(?);

data a;		* define initial data ;
	date_fld = '22dec2007'd;
run;

data b;
	set a;
	fiscal_year = %fiscal(date=date_fld);
	put 'Date is: ' date_fld date9. ', Fiscal Year is: 'fiscal_year;
run;

proc sql;
	select date_fld format yymmddd10., %fiscal(date=date_fld,format=yyq6.) from a ;
quit;

%put Fiscal YYYYMM is:%fiscal(date=%sysevalf('22dec2007'd),format=yymmn6.);
